@@ -22,8 +22,23 @@ pub(crate) mod wrap_string;
 
 const TEMPLATE: &str = include_str!("../assets/template.html");
 const ICON: &str = "help/icon.png";
+const RELOAD: &str = "\
+setInterval(function() {
+    $.ajax({
+        url: '/changed/',
+        contentType: 'json',
+        success: data => {
+            if (window.modified === undefined)
+                window.modified = data['modified'];
+            if (data['modified'] > window.modified) {
+                window.modified = data['modified'];
+                location.reload();
+            }
+        }
+    });
+}, 500);";
 
-fn load_main(yaml: Array<RcRepr>, v: &Anchors, mount: &str) -> Result<String, Error> {
+fn load_main(yaml: Array<RcRepr>, v: &Anchors, mount: &str, reload: bool) -> Result<String, Error> {
     let meta = &yaml[0];
     let bg = Background::new(meta)?;
     let outline = meta.get_default("outline", true, Node::as_bool)?;
@@ -35,6 +50,7 @@ fn load_main(yaml: Array<RcRepr>, v: &Anchors, mount: &str) -> Result<String, Er
     let theme = meta.get_default("theme", "serif", Node::as_str)?;
     let code_theme = meta.get_default("code-theme", "zenburn", Node::as_str)?;
     let (plugin_names, plugin_files) = js_plugin(meta)?;
+    let reload_script = if reload { RELOAD } else { "" };
     Ok(TEMPLATE
         .to_string()
         .replace("{%icon}", meta.get_default("icon", ICON, Node::as_str)?)
@@ -46,6 +62,7 @@ fn load_main(yaml: Array<RcRepr>, v: &Anchors, mount: &str) -> Result<String, Er
         .replace("{%code-theme}", code_theme)
         .replace("{%footer}", &footer(meta)?)
         .replace("{%slides}", &doc)
+        .replace("/* {%auto-reload} */", reload_script)
         .replace("/* {%option} */", &js_option(meta)?)
         .replace("/* {%style} */", style)
         .replace("/* {%plugin} */", &plugin_names)
@@ -54,7 +71,7 @@ fn load_main(yaml: Array<RcRepr>, v: &Anchors, mount: &str) -> Result<String, Er
 }
 
 /// Load YAML string as HTML.
-pub(crate) fn loader(yaml_str: &str, mount: &str) -> Result<String, IoError> {
+pub(crate) fn loader(yaml_str: &str, mount: &str, reload: bool) -> Result<String, IoError> {
     let (yaml, anchor) = parse(yaml_str).map_err(|s| IoError::new(ErrorKind::InvalidData, s))?;
     if yaml.len() < 2 {
         return Err(IoError::new(
@@ -62,7 +79,7 @@ pub(crate) fn loader(yaml_str: &str, mount: &str) -> Result<String, IoError> {
             "Missing metadata or slides".to_string(),
         ));
     }
-    load_main(yaml, &anchor, mount).map_err(|Error(name, pos)| {
+    load_main(yaml, &anchor, mount, reload).map_err(|Error(name, pos)| {
         IoError::new(
             ErrorKind::InvalidData,
             format!("{}:\n{}", name, indicated_msg(yaml_str, pos)),
